@@ -1,11 +1,10 @@
 #-*- coding:utf-8 -*-
-import json
 import logging
 import urllib2
 
 from celery import task
 from celery.signals import beat_init
-from djcelery.models import PeriodicTask, IntervalSchedule
+from djcelery.models import PeriodicTask
 
 from pingokio.domains.models import AvailabilityTestCase, CheckLog
 
@@ -43,13 +42,9 @@ def process_atc(atc_pk):
 
 def create_periodic_tasks(sender=None, **kwargs):
     logger.info("beat_init signal")
+    PeriodicTask.objects.filter(name__contains='atc').delete()
     for test in AvailabilityTestCase.objects.all():
-        test_name = 'atc' + str(test.pk)
-        if PeriodicTask.objects.filter(name=test_name).exists():
-            PeriodicTask.objects.filter(name=test_name).delete()
-        interval_schedule = IntervalSchedule(every=test.period, period='seconds')
-        interval_schedule.save()
-        PeriodicTask(name=test_name, task='pingokio.domains.tasks.process_atc', interval=interval_schedule, args=json.dumps([test.pk])).save()
+        test.create_simmetric_periodic_task()
         logger.debug('register task for %s' % test)
 
 beat_init.connect(create_periodic_tasks)
